@@ -1,14 +1,14 @@
 /***********************************************************************
-* SPDX-FileCopyrightText: 2020 Shubham <aryan100jangid@gmail.com>
-*
-* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
-***********************************************************************/ 
+ * SPDX-FileCopyrightText: 2020 Shubham <aryan100jangid@gmail.com>
+ *
+ * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ ***********************************************************************/
 
 #include "testFileTree.h"
 
 TestFileTree::TestFileTree()
+    : fl(new File("./autotests/core/dummy.txt", 20))
 {
-    fl = new File("./autotests/core/dummy.txt", 20);
 }
 
 TestFileTree::~TestFileTree()
